Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(161)

Unified Diff: src/crankshaft/arm64/lithium-codegen-arm64.cc

Issue 1409123003: [runtime] Avoid @@isConcatSpreadable lookup for fast path Array.prototype.concat (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: simplifications Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/crankshaft/arm64/lithium-codegen-arm64.cc
diff --git a/src/crankshaft/arm64/lithium-codegen-arm64.cc b/src/crankshaft/arm64/lithium-codegen-arm64.cc
index 292014a5d53d3638880363f01cf414934d0cd022..ecc5afd08f406b06694222d9ba94a79ec0468c8b 100644
--- a/src/crankshaft/arm64/lithium-codegen-arm64.cc
+++ b/src/crankshaft/arm64/lithium-codegen-arm64.cc
@@ -3471,11 +3471,13 @@ void LCodeGen::DoLoadKeyedFixed(LLoadKeyedFixed* instr) {
__ B(ne, &done);
if (info()->IsStub()) {
// A stub can safely convert the hole to undefined only if the array
// protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise
// it needs to bail out.
- __ LoadRoot(result, Heap::kArrayProtectorRootIndex);
+ __ LoadRoot(result, Heap::kArrayElementsProtectorRootIndex);
__ Ldr(result, FieldMemOperand(result, Cell::kValueOffset));
- __ Cmp(result, Operand(Smi::FromInt(Isolate::kArrayProtectorValid)));
+ __ Cmp(result,
+ Operand(Smi::FromInt(Isolate::kArrayElementsProtectorValid)));
DeoptimizeIf(ne, instr, Deoptimizer::kHole);
}
__ LoadRoot(result, Heap::kUndefinedValueRootIndex);
@@ -3471,11 +3471,13 @@ void LCodeGen::DoLoadKeyedFixed(LLoadKeyedFixed* instr) {
if (info()->IsStub()) {
// A stub can safely convert the hole to undefined only if the array
- // protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise
+ // protector cell contains (Smi) Isolate::kArrayElementsProtectorValid.
+ // Otherwise
// it needs to bail out.

Powered by Google App Engine
This is Rietveld 408576698